==> ah-form-builder-sample-0.6.20.tgz: package/es/components/app/fields-wrappers/Radio.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/components/app/fields-wrappers/Radio.js";
import React from 'react';
import RadioGroup from "../../../utils/radio/RadioGroup";
import Input from '../../../utils/inputs/TextInput';
export default function RadioWrapper(props) {
  var _React$useState = React.useState(null),
      value = _React$useState[0],
      setValue = _React$useState[1];

  var _React$useState2 = React.useState(false),
      other = _React$useState2[0],
      setOther = _React$useState2[1];

  var _React$useState3 = React.useState(''),
      otherValue = _React$useState3[0],
      setOtherValue = _React$useState3[1];

  var handleChange = function handleChange(e) {
    var newValue = e.target.value;

    if (newValue === 'Specify Others') {
      setOther(true);
    } else {
      setOther(false);
      setOtherValue('');
    }

    setValue(newValue);
  };

  var handleOtherChange = function handleOtherChange(e) {
    setOtherValue(e.target.value);
  };

  var options = [];

  if (props.data.config.optionReferenceId) {
    options = _.cloneDeep(props.predefined[props.data.config.optionReferenceId].options);
  }

  if (props.data.config.enableOther) {
    options.push({
      id: -1,
      name: 'Specify Others'
    });
  }

  if (other) {
    return [/*#__PURE__*/React.createElement(RadioGroup, {
      label: props.data.name,
      required: props.data.config.isRequired,
      helperText: props.data.config.helpText,
      options: options,
      labelProp: "name",
      valueProp: "name",
      value: value,
      handleChange: handleChange,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 35,
        columnNumber: 7
      }
    }), /*#__PURE__*/React.createElement(Input, {
      handleChange: handleOtherChange,
      value: otherValue,
      placeholder: "Specify Others",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 45,
        columnNumber: 7
      }
    })];
  }

  return /*#__PURE__*/React.createElement(RadioGroup, {
    label: props.data.name,
    required: props.data.config.isRequired,
    helperText: props.data.config.helpText,
    options: options,
    labelProp: "name",
    valueProp: "name",
    value: value,
    handleChange: handleChange,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 54,
      columnNumber: 5
    }
  });
}

==> ah-form-builder-sample-0.6.86.tgz: package/es/components/app/fields-wrappers/Radio.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/components/app/fields-wrappers/Radio.js";
import React from 'react';
import RadioGroup from "../../../utils/radio/RadioGroup";
import Input from '../../../utils/inputs/TextInput';
export default function RadioWrapper(props) {
  var _props$data2;

  var _React$useState = React.useState(null),
      value = _React$useState[0],
      setValue = _React$useState[1];

  var _React$useState2 = React.useState(false),
      other = _React$useState2[0],
      setOther = _React$useState2[1];

  var _React$useState3 = React.useState(''),
      otherValue = _React$useState3[0],
      setOtherValue = _React$useState3[1];

  var handleChange = function handleChange(e) {
    var newValue = e.target.value;

    if (newValue === 'Specify Others') {
      setOther(true);
    } else {
      setOther(false);
      setOtherValue('');
    }

    setValue(newValue);
  };

  var handleOtherChange = function handleOtherChange(e) {
    setOtherValue(e.target.value);
  };

  var options = [];

  if (props.data.config.optionReferenceId) {
    options = _.cloneDeep(props.predefined[props.data.config.optionReferenceId].options);
  }

  if (props.data.config.enableOther) {
    options.push({
      id: -1,
      name: 'Specify Others'
    });
  }

  if (other) {
    var _props$data;

    return [/*#__PURE__*/React.createElement(RadioGroup, {
      label: ((_props$data = props.data) == null ? void 0 : _props$data.locals) && Object.keys(props.data.locals).length !== 0 ? props.currentLang === 'en' ? props.data.name : props.data.locals.ar.name_ar : props.data.name,
      required: props.data.config.isRequired,
      helperText: props.data.config.helpText,
      options: options,
      labelProp: "name",
      valueProp: "name",
      value: value,
      handleChange: handleChange,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 35,
        columnNumber: 7
      }
    }), /*#__PURE__*/React.createElement(Input, {
      handleChange: handleOtherChange,
      value: otherValue,
      placeholder: "Specify Others",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 45,
        columnNumber: 7
      }
    })];
  }

  return /*#__PURE__*/React.createElement(RadioGroup, {
    label: ((_props$data2 = props.data) == null ? void 0 : _props$data2.locals) && Object.keys(props.data.locals).length !== 0 ? props.currentLang === 'en' ? props.data.name : props.data.locals.ar.name_ar : props.data.name,
    required: props.data.config.isRequired,
    helperText: props.data.config.helpText,
    options: options,
    labelProp: "name",
    valueProp: "name",
    value: value,
    handleChange: handleChange,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 54,
      columnNumber: 5
    }
  });
}
